@@ -1,13 +1,18 @@
-from .action import Action
-from ..core import Peripheral, Context
-from dataclasses import dataclass 
+from dataclasses import dataclass
+
 import evdev
 
+from .. import core
+from .action import Action
+from .context import Context
+
+
 @dataclass
 class Redirect(Action):
     """The default action that is emitted. It simply redirects the event from one device to another."""
+
     event: evdev.InputEvent
 
-    def emit(self, device: Peripheral, context: Context):
+    def emit(self, device: core.Peripheral, context: Context) -> None:
         device.ui.write(self.event.type, self.event.code, self.event.value)
         device.ui.syn()
